import csv
from collections import defaultdict, Counter


def write_to_csv_by_field(field, data):
    with open(f'{field}.csv', 'w', encoding='utf-8', newline='') as f:
        writer = csv.writer(f)
        writer.writerow(['Field', 'Value', 'Count'])  # 写入表头
        field_counts = Counter()  # 使用Counter来统计值出现的次数
        for row in data:
            field_counts[row[field]] += 1  # 统计每个值的出现次数
        for value, count in field_counts.items():  # 遍历每个值及其计数
            writer.writerow([field, value, count])  # 将值和计数写入CSV文件


# 打开文件并读取数据
with open('types.csv', 'r', encoding='utf-8') as f:
    reader = csv.DictReader(f)
    data = [row for row in reader]

# 使用 defaultdict 来初始化 field_counts，这样当不存在的键被访问时，会自动创建一个默认值字典
field_counts = defaultdict(Counter)

# 提取每个字段中的字符串，并统计种类和数量
for row in data:
    for field in ['原创与否', 'CP类型', '年代背景', '小说主题', '视角']:
        value = row[field]
        # 使用 defaultdict 的特性，不存在的键会自动创建默认值字典，这里默认值是 0
        field_counts[field][value] += 1

        # 将不同字段的数据保存在不同的CSV文件中
write_to_csv_by_field('原创与否', data)
write_to_csv_by_field('CP类型', data)
write_to_csv_by_field('年代背景', data)
write_to_csv_by_field('小说主题', data)
write_to_csv_by_field('视角', data)