import csv


def extract_info(filename):
    with open(filename, 'r', encoding='utf-8') as f:
        reader = csv.reader(f)
        types_info = []  # 创建一个空列表来保存类型信息
        # 遍历csv文件的每一行
        for row in reader:  # 遍历每一行
            # 获取第三列的内容，通常为类型信息
            types = row[2]
            # 使用字符串的split方法分割类型信息中的各个部分
            parts = types.split('-')  # 使用'-'作为分隔符分割字符串
            # 如果分割成功，且分割的部分数量正确
            if len(parts) == 5:
                # 从分割结果中提取所需的信息，并保存在新的行中
                type_info = {
                    '原创与否': parts[0],
                    'CP类型': parts[1],
                    '年代背景': parts[2],
                    '小说主题': parts[3],
                    '视角': parts[4]
                }
                types_info.append(type_info)  # 将新行添加到列表中
        return types_info  # 返回类型信息列表


def write_to_csv(filename, types_info):  # 创建一个新的函数来写入数据到csv文件
    with open('types.csv', 'w', newline='', encoding='utf-8') as csv_file:  # 打开输出文件
        fields = ['原创与否', 'CP类型', '年代背景', '小说主题', '视角']
        writer = csv.DictWriter(csv_file, fieldnames=fields)
        writer.writeheader()  # 写入字段名作为表头
        for type_info in types_info:  # 遍历类型信息列表
            writer.writerow(type_info)  # 将新行写入到输出文件中


# 调用函数，输入你的csv文件路径，这里使用了一个示例路径：D:\\晋江数据采集\\books_01.csv
types_info = extract_info('D:\\晋江数据采集\\all_books_1080.csv')  # 读取数据并获取类型信息列表
write_to_csv('types.csv', types_info)  # 将类型信息写入到新的csv文件中